@@ -4,9 +4,8 @@ use strict;
 use utf8;
 use Modern::Perl;
 
-our $VERSION = '0.005';    # VERSION
-use Moose;
-use MooseX::Types::DBIx::Class 'ResultSource';
+our $VERSION = '0.010';    # VERSION
+use Moo;
 use namespace::autoclean -also => qr{\A _}xms;
 
 my %ATTR = (
@@ -16,10 +15,10 @@ my %ATTR = (
 );
 
 while ( my ( $name, $default ) = each %ATTR ) {
-    has $name => ( is => 'ro', isa => 'Str', default => $default );
+    has $name => ( is => 'ro', default => sub {$default} );
 }
 
-has applies_to => ( is => 'ro', default => sub { [ResultSource] } );
+has applies_to => ( is => 'ro', default => sub { ['ResultSource'] } );
 
 sub violates {
     my $source = shift->element;
@@ -28,7 +27,6 @@ sub violates {
 }
 
 with 'DBIx::Class::Schema::Critic::Policy';
-__PACKAGE__->meta->make_immutable();
 1;
 
 # ABSTRACT: Check for DBIx::Class::Schema::ResultSources without primary keys
@@ -48,7 +46,7 @@ DBIx::Class::Schema::Critic::Policy::NoPrimaryKey - Check for DBIx::Class::Schem
 
 =head1 VERSION
 
-version 0.005
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -63,10 +61,17 @@ L<DBIx::Class::ResultSource|DBIx::Class::ResultSource> has zero primary columns.
 
 =head1 ATTRIBUTES
 
+=head2 description
+
+"No primary key"
+
+=head2 explanation
+
+"Tables should have one or more columns defined as a primary key."
+
 =head2 applies_to
 
-This policy applies to L<MooseX::Types::DBIx::Class|MooseX::Types::DBIx::Class>
-I<ResultSource>s.
+This policy applies to L<ResultSource|DBIx::Class::ResultSource>s.
 
 =head1 METHODS
 
